fitTsfmUpDn returns an object tsfmUpDn. It supports generic
function such as summary, predict, plot and print.
It is also a list object containing Up and Dn. Both Up
and Dn are class of "tsfm". As a result, for each list
object, The generic function such as print, plot, predict
and summary methods exist for both Up and Dn. Also, the
generic accessor functions coef, fitted, residuals and
fmCov can be applied as well.
An object of class "tsfmUpDn" is a list containing Up and Dn:
- Up
An object of tsfm fitted by fitTsfm for the up market;
- Dn
An object of tsfm fitted by fitTsfm for the down market;
and others useful items:
- call
Function call.
- data
Original data used but converted to xts class.
Each object of tsfm contains :
- asset.fit
list of fitted objects for each asset. Each object is of
class lm if fit.method="LS" or "DLS", class lmRob if
the fit.method="Robust"
- alpha
length-N vector of estimated alphas.
- beta
N x 1 matrix of estimated betas.
- r2
length-N vector of R-squared values.
- resid.sd
length-N vector of residual standard deviations.
- call
the matched function call.
- data
xts data object containing the assets and factors.
- asset.names
asset.names as input.
- factor.names
factor.names as input.
- fit.method
fit.method as input.
Where N is the number of assets and T is the
number of time periods.